@@ -31,7 +31,7 @@ def layout_css(accent_color, aspect):
                 },
                 "^.InView-Title .Arrows.Prev-Btn, ^.InView-Last .Arrows.Next-Btn, ^.InView-Title .Slide-Number, ^.InView-Title .Progress-Box": {
                     "display": "none !important",
-                },  # still should be clickable
+                }, 
                 ".Slide-Number" : { # slide number
                     "position": "absolute !important",
                     "right": "0 !important",
@@ -42,6 +42,7 @@ def layout_css(accent_color, aspect):
                     "cursor": "help",
                     "^.Menu-Item":{"color": "var(--fg2-color) !important",},
                     "^:focus,^:active": {"box-shadow": "none !important"},
+                    "@media print": {"display": "none !important",}, # each slide gets its own slide number
                 },
                 ".Progress-Box": {
                     "margin": "0 !important",
@@ -50,6 +51,7 @@ def layout_css(accent_color, aspect):
                     "left":"0 !important",
                     "bottom": "0 !important",
                     "background": "var(--bg2-color) !important",
+                    "@media print": {"display": "none !important",}, # each slide gets its own progressbar
                     ".Progress" : {
                         "margin": "0 !important",
                         "padding": "0 !important",
@@ -129,7 +131,11 @@ def layout_css(accent_color, aspect):
                         "border": "1px solid red",
                         "display": "block",
                     },
-                    ".export-only": {"display": "none !important"},
+                    "^.HideSlide *": {"visibility": "hidden !important",},
+                    "@media print": {
+                        "^.HideSlide": {"visibility": "visible !important",},
+                        "^.HideSlide *": {"visibility": "inherit !important",},
+                    },
                     ".jp-OutputArea": {
                         "width": "100% !important",
                         "height": "auto !important", # This is must for layout
@@ -148,7 +154,10 @@ def layout_css(accent_color, aspect):
                     "border": "1px solid var(--bg3-color)",
                     "border-radius": "0.2em",
                 },
-                ".export-only": {"display": "none !important"},
+                ".export-only, .print-only": {
+                    "display": "none !important",
+                    "@media print": {"display": "revert !important",},
+                    },
                 ".widget-inline-hbox": {
                     ".widget-label": {"color": "var(--fg1-color)"},
                     ".widget-readout": {
@@ -755,12 +764,12 @@ def zoom_hover_css():
     )
 
 
-def background_css(opacity=0.75, filter='blur(2px)', contain=False):
+def background_css(sel, opacity=0.75, filter='blur(2px)', contain=False, _id=''):
     if filter and not '(' in str(filter):
         raise ValueError(f"blur expects a CSS filter function like 'blur(2px)', 'invert()' etc. or None, got {filter}")
     
-    uclass = get_unique_css_class()
-    return f"""{uclass} .BackLayer {{
+    # sel depends on where image is placed
+    return f"""{sel} .BackLayer {{
         position: absolute !important;
         top:0 !important;
         left:0 !important;
@@ -770,25 +779,27 @@ def background_css(opacity=0.75, filter='blur(2px)', contain=False):
         overflow:hidden;
         margin:0;
     }}
-    {uclass} .BackLayer :is(img, svg) {{
+    {sel} .BackLayer :is(img, svg) {{
         position: absolute;
         left:50% !important;
         top:50% !important;
         transform: translate(-50%,-50%) !important; /* Make at center */
         width: 100%;
         height: 100%;
+    }}
+    {sel} #{_id}.BackLayer :is(img, svg) {{
         object-fit:{('contain' if contain else 'cover')} !important;
         filter: {filter};
         opacity:{opacity};
-    }}
-    {uclass} .BackLayer svg {{
+    }}  
+    {sel} #{_id}.BackLayer svg {{
         max-width: {('100%' if contain else '')} !important;
         max-height: {('100%' if contain else '')} !important;
         width: {('' if contain else 'auto')} !important;
         min-width: {('' if contain else '100%')} !important;
         min-height: {('' if contain else '100%')} !important;
     }}
-    {uclass} .BackLayer.jupyter-widgets-disconnected {{
+    {sel} .BackLayer.jupyter-widgets-disconnected {{
         display:none;
     }}
     """
