@@ -79,14 +79,15 @@ class BaseSlides:
 
     def on_load(self, func):
         """
-        Decorator for running a function when slide is loaded into view. No return value is required.
+        Decorator for running a `func(slide)` when slide is loaded into view.
         Use this to e.g. notify during running presentation. func accepts single arguemnet, slide.
+        Return value could a cleanup function (which also accepts slide as single argument) executed when slide exits.
         
         See `Slides.docs()` for few examples.
 
         ::: note-warning
-            - Do not use this to change global state of slides, because that will affect all slides.
-            - This can be used single time per slide, overwriting previous function.
+            - If you use this to change global state of slides, return a clean up function which accepts slide as argument.
+            - This can be used only single time per slide, overwriting previous function.
         """
         self.verify_running('on_load decorator can only be used inside slide constructor!')
         self.this._on_load_private(func) # This to make sure if code is correct before adding it to slide
@@ -404,9 +405,8 @@ class BaseSlides:
         
         with self.build(-1) as s:
             s.set_css({
-                '--bg1-color': 'linear-gradient(45deg, var(--bg3-color), var(--bg2-color), var(--bg3-color))',
                 '.highlight': {'background':'#8984'}
-            }) 
+            }, bg1 = 'linear-gradient(45deg, var(--bg3-color), var(--bg2-color), var(--bg3-color))')
             self.styled('## Layout and Theme Settings', 'info', border='1px solid red').display()
             self.doc(self.settings,'Slides', members=True,itself = True).display()
                 
@@ -456,6 +456,7 @@ class BaseSlides:
                     t = datetime.datetime.now()
                     time = t.strftime('%H:%M:%S')
                     self.notify(f'Notification at {time} form slide {slide.index} and frame {slide.indexf}', timeout=5)
+                    return lambda s: self.notify('x') # clear notification immediately on exit by sending 'x'
             
             self.write(
                 [self.doc(self.dl.interact,'ipyslides.dashlab')], 
