@@ -1,6 +1,6 @@
 # Template for building HTML from slides 
 
-def doc_html(code_css, style_css, content, script, click_btns, height, css_class, bar_loc):
+def doc_html(code_css, style_css, content, script, click_btns, css_class, padding_bottom):
     return f'''<!DOCTYPE html>
 <html lang="en">
 <head>
@@ -13,7 +13,7 @@ def doc_html(code_css, style_css, content, script, click_btns, height, css_class
     <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/2.0.3/jquery.min.js"></script> 
     
     <style>{style_css}</style>
-    {slides_css.replace('__HEIGHT__', height).replace('__WHERE__',bar_loc)}
+    {slides_css.replace("__PADBTM__",str(padding_bottom))}
     {code_css}
 
     <!-- Custom stylesheet, it must be in the same directory as the html file -->
@@ -45,14 +45,14 @@ def doc_html(code_css, style_css, content, script, click_btns, height, css_class
 </head>
 <body>
 <div>
-    <div class="click-wrapper"> {click_btns} </div>
+    {click_btns}
     <!-- Classes below work for both scenerios -->
     <div class="{css_class}">
     {content}
     </div>
 </div>
 </body>
-{script}
+{script.replace("__PADBTM__",str(padding_bottom))}
 </html>
 '''
 
@@ -63,18 +63,6 @@ a:hover {text-decoration:underline !important;}
 p {margin-block: 0.25em !important;}
 pre {white-space: break-spaces;} /* General rule unless specified in elements */
 .toc-item {margin-block: 0.25em}
-.click-wrapper {
-    position: fixed !important;
-    left:calc(100% - 150px) !important; /* extra space for slide number */
-    bottom:2px !important;
-    width: 110px !important;
-    height: 21px !important;
-    display:flex !important;
-    z-index: 6 !important;
-    justify-content: space-evenly !important;
-}
-.click-wrapper .clicker {display:block;flex-grow:1;color:var(--accent-color);text-align:center;font-size:14px;height:21px;text-decoration:none !important;opacity:0.4;}
-.click-wrapper .clicker:hover {color:var(--fg1-color);opacity:1;}
 .SlidesWrapper {
 	scroll-snap-type: x mandatory !important;
     display: flex !important;
@@ -113,21 +101,16 @@ section .SlideBox > .Progress {
     height: 2px !important;
     width: 100% !important;
     position: absolute !important;
-    left:0 !important;__WHERE__:0 !important;
+    left:0 !important;
+    bottom: 0 !important;
 }
 section:first-of-type .SlideBox > .Progress {width: 0 !important;}  /* avoid non-zero progress in title of print*/
-section .SlideArea {
-    /* Will be added by export */
-	margin: auto !important;
-	padding: 16px !important;
-    box-sizing: border-box !important;
-}
 .SlidesWrapper .Footer { 
     padding: 0 !important; margin: 0 !important; 
     position: fixed !important;
     left:0;
     width: 100%;
-    bottom: 2px !important;
+    bottom: -2px !important; /* something off */
     overflow: hidden !important;
 }
 .SlidesWrapper .Footer.NavHidden {
@@ -161,28 +144,22 @@ section .SlideArea {
 .SlidesWrapper .Number {
     color:var(--fg2-color);
     position:absolute;
-    right:8px;
-    bottom:6px;
-    font-size:16px;
+    right:6px;
+    bottom:3px;
+    font-size:12px;
     z-index:5;
 }
 
 @media print {
     * {
-        --contentScale : 1 !important; /* Defualt for printing at same value */
         -webkit-print-color-adjust: exact !important;
         print-color-adjust: exact !important;
         color-adjust: exact !important;
         ::-webkit-scrollbar { height: 0 !important; width: 0 !important; }
     }
-    @page {
-        size: 210mm __HEIGHT__; /* 10 inch x decided by aspect by user*/
-        margin-top: 0 !important;
-        margin-right: 0 !important;
-        margin-left: 0 !important;
-        margin-bottom: 0 !important;
-    }
+    /* Page size is set in style_css */
     .SlidesWrapper {
+        --contentScale : 1 !important; /* Defualt for printing at same value */
         display: flex !important;
         flex-direction: column !important;
         overflow: hidden !important;
@@ -198,7 +175,7 @@ section .SlideArea {
         page-break-inside: avoid !important;
         page-break-after: always !important;
         overflow: hidden !important; /* otherwise it throws text to next page */
-        padding-bottom: 25px !important; /* for avoiding overflow to bottom,25px is same as under SlideArea */
+        padding-bottom: __PADBTM__px !important; /* for avoiding overflow to bottom,same as under SlideArea */
     }
     section:last-of-type {
         page-break-after: avoid !important;
@@ -212,9 +189,7 @@ section .SlideArea {
         position: static !important; /*override from document as printing absolute is issue */
         overflow: hidden !important;
         page-break-inside: avoid !important;
-    }
-    .Slides-ShowFooter .SlideArea {
-        --paddingBottom: 25px; /* Default at sacle 1 its at bottom, unlike slides in Notebook, so 2px more*/
+        --paddingBottom: __PADBTM__px; /* fixed for printing, padding set in style_css */
     }
 }
 </style>
