@@ -14,6 +14,7 @@ from ipywidgets.widgets.trait_types import InstanceDict
 from ..formatters import fix_ipy_image, code_css, htmlize
 from ..utils import html, today, _clipbox_children, get_clips_dir, set_dir
 from . import intro, styles, _layout_css
+from ..dashlab import disabled
 
 
 class ConfigTraits(HasTraits):
@@ -153,13 +154,36 @@ class Fonts(ConfigTraits):
 @fix_sig    
 class Footer(ConfigTraits):
     "Set footer attributes of slides."
-    text = Unicode('IPySlides')
-    numbering = Bool(True)
-    date = Unicode("today", allow_none=True)
+    text = Unicode('IPySlides', help="Set footer text. Can use Markdown")
+    numbering = Bool(True, help="Show/hide slide numbering in footer.")
+    date = Unicode("today", allow_none=True, help="Set date string or use 'today' for current date.")
+    controls = Bool(True, help="Show/hide controls like next/prev buttons and clickers in PDF/export mode.")
+    progress = Bool(True, help="Show/hide progress bar at bottom of slides.")
+    _print_padding = 23 # internal use only
 
     def _apply_change(self,change):
-        if self.main._slides._current:
-            self.main._get_footer(self.main._slides._current, update_widget=True)
+        # change is None when called as footer(...), so we update all things together
+        wgts = self.main._widgets
+        wgts.htmls.footer.value = self._to_html() + self.main._get_clickers()
+        wgts._snum.layout.display = "" if self.numbering else "none" # show/hide slide number
+        wgts._progbar.layout.display = "" if self.progress else "none" # show/hide progress bar
+        self._print_padding = 23 if any([self.text, self.date]) else 16 # 16 is same around all sides unless footer needs more
+        wgts.iw._fkws = {"bar": self.progress, "snum": self.numbering, "pad": self._print_padding} # set before sending rescale message
+        wgts.controls.layout.visibility = "visible" if self.controls else "hidden"
+        wgts.iw.msg_tojs = 'RESCALE' # sets padding etc
+
+        if not self.controls:
+            self.main._slides.notify("Navigation controls hidden. But keyboard is still working!")
+
+    
+    def _to_html(self):
+        style = 'white-space:nowrap;display:inline;margin-block:0;padding-left:8px;'
+        inner = self.text
+        if self.date:
+            inner += (
+                "<span style='white-space:pre'> | </span>" if inner else ""
+            ) + f'{today(fg = "var(--fg2-color)") if self.date == "today" else self.date}'
+        return htmlize(f'<p markdown="1" style="{style}">{inner}</p>') 
 
 @fix_sig
 class Layout(ConfigTraits):
@@ -183,7 +207,6 @@ class Layout(ConfigTraits):
 @fix_sig
 class Toggle(ConfigTraits):
     "Toggle ON/OFF checks in settings panel."
-    navgui = Bool(True) 
     reflow = Bool(False)
     notes  = Bool(False)
     toast  = Bool(True)
@@ -273,6 +296,8 @@ class Settings:
         self._widgets.theme.observe(lambda c: self.theme(value=c.new), names=["value"])
         self._widgets.checks.reflow.observe(self._update_theme, names=["value"])
         self._widgets.buttons.info.on_click(self._show_info)
+        self._widgets.buttons.print.on_click(self._print_pdf)
+        self._widgets.buttons.print2.on_click(self._print_pdf)
         self._widgets.htmls.toast.observe(self._toast_on_value_change, names=["value"])
         self._wslider.observe(self._update_size, names=["value"])
         self._tgl_fscreen.observe(self._toggle_fullscreen, names=["value"])
@@ -281,7 +306,6 @@ class Settings:
         self._widgets.toggles.laser.observe(self._toggle_laser, names=["value"])
         self._widgets.toggles.draw.observe(self._toggle_overlay, names=["value"])
         self._tgl_menu.observe(self._toggle_menu, names = ["value"])
-        self._widgets.checks.navgui.observe(self._toggle_nav_gui, names=["value"])
         self._update_theme({'owner':'layout'})  # Trigger Theme with aspect changed as well
         self._update_size(change=None)  # Trigger this as well
         self._widgets.panelbox.right_sidebar.children = _clipbox_children() # Set clipbox children
@@ -318,20 +342,40 @@ class Settings:
 
             self._widgets.htmls.toast.value = "" # Reset to make a new signal
     
+    def _print_pdf(self, btn):
+        with disabled(self._widgets.buttons.print,self._widgets.buttons.print2): # disable both buttons to avoid multiple clicks
+            self._slides.notify("Loading PDF window… <br>Use <code class='info'>Save as PDF</code> to preserve links.", timeout=5)
+            merge_frames = True if btn is self._widgets.buttons.print2 else False
+            
+            # Update frame counts first per slide for js side
+            self._widgets.iw._nfs = {s.number: 1 if merge_frames else s.nf for s in self._slides}
+            
+            # Update frames indices for print
+            parts = {}
+            for slide in self._slides:
+                slide._set_print_css(merge_frames = merge_frames)
+                if slide._fidxs and not merge_frames: # no parts if no frames or merge frames
+                    frms = []
+                    for frm in slide._fidxs:
+                        if isinstance(frm, int):
+                            frms.append({'row': frm - 1, 'col': None})
+                        elif isinstance(frm, tuple):
+                            frms.append({'row': frm[0] - 1, 'col': frm[1]})
+                        elif isinstance(frm , range):
+                            frms.append([*range(getattr(slide, '_frame_top',0)),*frm]) # 
+                        
+                    parts[slide.number] = frms
+                    
+            self._widgets.iw._pfs = parts
+            # Send message to JS to start print
+            self._widgets.iw.msg_tojs = 'PRINT'
+    
     def _show_info(self, btn):
         self._widgets.iw.send({
             "content": html('',[intro.instructions]).value,
             "timeout": 120000 # 2 minutes
         })
 
-    def _toggle_nav_gui(self, change):
-        visible = change.new
-        self._widgets.controls.layout.visibility = "visible" if visible else "hidden"
-        self._widgets.iw.msg_tojs = 'RESCALE' # sets padding etc
-
-        if not visible:
-            self._slides.notify("Navigation controls hidden. But keyboard is still working!")
-    
     def _resolve_img(self, src, width):
         if isinstance(src, Path):
             src = str(src)  # important for svg checking below
@@ -347,42 +391,21 @@ class Settings:
                 except:
                     return self._resolve_img(SVG(src)._repr_svg_(), width=width)
         return ''
-
-    def _get_footer(self, slide, update_widget=False):
-        "Get footer text. `slide` is a slide object."
-        if (type(slide).__name__ != "Slide") and (
-            type(slide).__module__.split(".")[0] != "ipyslides"
-        ):
-            raise TypeError(f"slide should be Slide object, not {type(slide)}")
-
-        text, numbering, date = self.footer.text, self.footer.numbering, self.footer.date
-
-        if any([text, date]):
-            self._slides._box.add_class("Slides-ShowFooter")
-        else:
-            self._slides._box.remove_class("Slides-ShowFooter")
-
-        if date:
-            text += (
-                "<span style='white-space:pre'> | </span>" if text else ""
-            ) + f'{today(fg = "var(--fg2-color)") if date == "today" else date}'
+    
+    def _get_clickers(self): # in PDF/export mode
+        if len(self._slides) < 5 or not self.footer.controls:
+            return '' # no clicks for few slides, or when navigation UI is off
         
-        if numbering and update_widget:
-            self._slides.widgets._snum.layout.display = ""
-        else:
-            self._slides.widgets._snum.layout.display = "none" # hide slide number
-
-        style = 'white-space:nowrap;display:inline;margin-block:0;padding-left:8px;'
-        text = htmlize(f'<p markdown="1" style="{style}">{text}</p>') 
-        
-        if update_widget:
-            self._widgets.htmls.footer.value = text
-
-        return text
+        items = [getattr(item,'_sec_id','') for item in self._slides]
+        imax = len(items) - 1
+        items = [items[i] for i in [0, imax//4,imax//2, 3*imax//4, imax]]
+        labels = '●●●●●'
+        links = "".join(f'<a href="#{key}" class="clicker">{label}</a>' for (label,key) in zip(labels,items))
+        return f'<div class="click-wrapper print-only"> {links} </div>' 
 
     def _update_size(self, change):
-        self._widgets.mainbox.layout.height = "{}vw".format(
-            int(self._wslider.value / self.layout.aspect)
+        self._widgets.mainbox.layout.height = "{:.1f}vw".format( # 1/10 mm is below usual broweser resolution
+            self._wslider.value / self.layout.aspect
         )
         self._widgets.mainbox.layout.width = "{}vw".format(self._wslider.value)
         self._update_theme({'owner':'layout'})  # change aspect for Linked Output view too
