@@ -5,12 +5,14 @@ from contextlib import contextmanager, suppress
 from functools import wraps
 from IPython.display import display
 from IPython.utils.capture import RichOutput
+from ipywidgets import HTML as ipwHTML
 
 from . import styles
 from ..utils import XTML, html, _styled_css, _build_css
 from ..xmd import capture_content
 from ..formatters import _Output, widget_from_data
-from ._layout_css import background_css
+from ._layout_css import background_css, get_unique_css_class
+from .styles import collapse_node
 
 class Vars:
     """Container for markdown slide variables, to see and update variables
@@ -22,6 +24,9 @@ class Vars:
     - `slides[:].vars.update(theme='dark')` updates variable 'theme' on all slides
     - `slides[1:3].vars.pop('title')` removes variable 'title' from slide 1 and 2 only
     - `slides[0].vars.scope` see variables with scope set on slide 0
+    
+    ::: note-tip
+        If variables are not set on slide, they are picked from notebook scope if `Auto Rebuild` is enabled in side panel.
     """
     def __init__(self, *slides):
         self._slides = slides
@@ -80,7 +85,7 @@ class Slide:
         self._app = app
             
         self._css = ''
-        self._bg_image = ''
+        self._bg_ikws = {} # store background image keywords only to save memory
         self._number = number
         self._index = number if number == 0 else None # First slide should have index ready
         self._animation = None
@@ -89,15 +94,17 @@ class Slide:
         self._esc_vars = {} # store escaped variables for rebuilds form build content
         self._set_defaults()
         self.vars = Vars(self) # to access variables info and update them
+        self._alt_print = ipwHTML(layout={'margin':'0'}).add_class('print-only') # alternate print content for this slide which is shown dynamically on slides
 
-        if not self._contents: # show slide number hint there
+        if not self._contents: # show slide number hint there at first creation
             self.set_css({
                 f' > .jp-OutputArea:empty:after': {
                     'content': f'"{self!r}"',
                     'color': 'var(--accent-color)',
                     'font-size': '2em',
                 }
-            })
+            }) # This will be removed when content is added or bg image is set
+
     
     def __setattr__(self, name: str, value):
         if not name.startswith('_') and hasattr(self, name):
@@ -105,8 +112,9 @@ class Slide:
         self.__dict__[name] = value
     
     def _set_defaults(self):
-        if hasattr(self,'_on_load'):
-            del self._on_load # Remove on_load function
+        for attr in ['_on_load', '_on_exit', '_fsep']:
+            if hasattr(self, attr):
+                delattr(self, attr) # reset these attributes if any
     
         self._notes = '' # Reset notes
         self._citations = {} # Reset citations
@@ -120,7 +128,8 @@ class Slide:
         self._has_top_frame = True
         self._set_refs = True
         self._toc_args = () # empty by default
-        self._widget.add_class(f"n{self.number}").remove_class("Frames") # will be added by fsep
+        self._widget.add_class(f"n{self.number}").remove_class("base") # will be added by fsep
+        self._tcolors = {} # theme colors for this slide only
   
     def _set_source(self, text, language):
         "Set source code for this slide. If"
@@ -134,7 +143,9 @@ class Slide:
     def _on_load_private(self, func):
         with self._app._hold_running(): # slides will not be running during switch, so make it safe
             with capture_content() as cap: # check if code is correct
-                func(self)
+                out = func(self)
+                if callable(out):
+                    out(self) # test call to raise error if any
             
             if cap.outputs or cap.stdout:
                 raise Exception('func in on_load(func) should not print or display anything!')
@@ -145,18 +156,14 @@ class Slide:
         self._on_load = func # This will be called in main app
     
     def _run_on_load(self):
-        "Called when a slide is loaded into view. Use it to register notifications etc."
-        self._widget.layout.height = '100%' # Trigger a height change to reset scroll position
-        start = time.time()
-        self._app.widgets.htmls.bglayer.value = self._bg_image
-
-        try: # Try is to handle errors in on_load, not for attribute errors, and also finally to reset height
-            if hasattr(self,'_on_load') and callable(self._on_load):
-                self._on_load(self) # Now no need to raise Error as it is already done in _on_load_private, and no one can handle it either
-        finally:
-            if (t := time.time() - start) < 0.05: # Could not have enought time to resend another event
-                time.sleep(0.05 - t) # Wait at least 50ms, (it does not effect anything else) for the height to change from previous trigger
-            self._widget.layout.height = '' # Reset height to auto
+        "Called when a slide is loaded into view. Use it to register notifications, auto toggle laser pointer etc."
+        # To ensure previous _on_exit and the new _on_load are called properly, try finally
+        try:
+            if callable(getattr(self,'_on_exit', None)):
+                self._on_exit(self) # call exit function of previous slide if any
+        finally: 
+            if callable(getattr(self,'_on_load', None)):
+                self._on_exit = self._on_load(self) # will be called when this slide is exited
         
     def __repr__(self):
         return f'Slide(number = {self.number}, index = {self.index}, nf = {self.nf})'
@@ -175,6 +182,9 @@ class Slide:
         
         with self._app._set_running(self):
             with capture_content() as captured:
+                display(html('span', '', id = self._sec_id, css_class='Slide-UID'), # span to not occupy space, need to remove from frames later.
+                    metadata={'skip-export':'export html assign itself'})  # to register section id in DOM
+                display(self._alt_print, metadata={'skip-export':'export html takes css itself'}) # alternate print content if any should be on top frame
                 yield captured
             
             if (self.number == 0) and self._fidxs:
@@ -232,7 +242,6 @@ class Slide:
         return tuple([v for v in self._has_vars if not v in self._md_vars]) # only those not set on slide
 
     def _reset_toc(self):
-        self._app._sec_id2dom() # for clickable links
         items = []
         for s in self._app[:self.index]:
             if s._section:
@@ -350,7 +359,33 @@ class Slide:
             0 < self.indexf < (self.nf - 1)
         ]) and hasattr(self,'_on_load') and callable(self._on_load):
             self._on_load(self)
-                
+    
+    def _frame_css(self, index):
+        if not self._fidxs:
+            return ''
+        
+        if index < 0 or index >= self.nf:
+            raise IndexError(f"Frame index {index} out of range for slide {self.number} with {self.nf} frames!")
+        
+        start, nrows, ncols, first = 1, self._fidxs[index], 0, getattr(self, '_frame_top',0)
+        if isinstance(nrows, tuple):
+            nrows, ncols = nrows
+        elif isinstance(nrows, range): # not joined
+            start, nrows = nrows.start, nrows.stop
+        
+        def hide(b): 
+            props = {'^, ^ *':{'visibility': ('hidden' if b else 'inherit') + '!important'}} # hide all and nested
+            return props if self.stacked else {**collapse_node(b), '@media print': props}
+            
+        return _styled_css({ # base class is important to avoid CSS clashes while printing clones
+            f'^.n{self.number}.base > .jp-OutputArea > .jp-OutputArea-child': {
+                f'^:not(:nth-child(n + {start}):nth-child(-n + {nrows}))': hide(True), # start through nrows
+                f'^.jp-OutputArea-child.jp-OutputArea-child:nth-child(-n + {first})': hide(False), # initial objs on each, increase spacificity 
+                **({f'^:nth-child({nrows}) .columns.writer:first-of-type > div:nth-child(n + {ncols+1})': { # avoid nested columms
+                    'visibility': 'hidden !important', # enforce this instead of jumps in height
+                }} if isinstance(self._fidxs[index], tuple) else {}), 
+            },
+        }).value
     
     def _show_frame(self, which):
         if self._fidxs:
@@ -361,29 +396,7 @@ class Slide:
             else:
                 return False
             
-            start, nrows, ncols, first = 1, self._fidxs[self.indexf], 0, getattr(self, '_frame_top',0)
-            if isinstance(nrows, tuple):
-                nrows, ncols = nrows
-            elif isinstance(nrows, range): # not joined
-                start, nrows = nrows.start, nrows.stop
-
-            self._fsep.value = _styled_css({
-                f'^.n{self.number} > .jp-OutputArea > .jp-OutputArea-child': {
-                    f'^:not(:nth-child(n + {start}):nth-child(-n + {nrows}))': { # start through nrows
-                        'height': '0 !important',
-                    },
-                    f'^.jp-OutputArea-child.jp-OutputArea-child:nth-child(-n + {first})': { # initial objs on each, increase spacificity 
-                        'height': 'unset !important',
-                    },
-                    f'^.jp-OutputArea-child.jp-OutputArea-child:nth-child({len(self.contents) + 1})': { # for references, shown after contents
-                        'height': 'unset !important'
-                    },
-                    **({f'^:nth-child({nrows}) .columns.writer:first-of-type > div:nth-child(n + {ncols+1})': { # avoid nested columms
-                        'visibility': 'hidden !important', # enforce this instead of jumps in height
-                    }} if isinstance(self._fidxs[self.indexf], tuple) else {}), 
-                },
-            }).value
-
+            self._fsep.value = self._frame_css(self.indexf)
             self._update_view(which)
             return True # indicators required
         else:
@@ -399,7 +412,13 @@ class Slide:
         "Jump to previous frame and return True. If no previous frame, returns False"
         return self._show_frame('prev')
     
-
+    def _set_print_css(self, merge_frames = False):
+        if merge_frames:
+            if hasattr(self, '_fsep'):
+                self._fsep.value = '' # Just let free print go
+        elif hasattr(self, '_fsep'): 
+            self._fsep.value = self._frame_css(0) # set first frame for print mode without other actions
+            
     def _reset_indexf(self, new_index, func): 
         old = int(self.indexf) # avoid pointing to property
         self._indexf = new_index
@@ -432,6 +451,9 @@ class Slide:
             delattr(self, '_refs') # added later  only if need
         
         if all([self._citations, self._set_refs, self._app.cite_mode == 'footnote']): # don't do in inline mode
+            if self.nf > 1:
+                return self._app.notify(f"Slide {self.number} has frames, so refs should be set explicitly!", 5)
+        
             self._refs = html('div', # need to store attribute for export
                 sorted(self._citations.values(), key=lambda x: x._id), 
                 css_class='Citations', style = '')
@@ -453,9 +475,10 @@ class Slide:
         self._app.html('style', 
             f'''.SlideArea.n{self.number}.n{self.number} > .jp-OutputArea {{
                 top: {value}% !important;
+                height: {100 - value}% !important; 
                 margin-top: 0 !important;
             }}''' # each frames get own yoffset, margin-top 0 is important to force top to take effect
-        ).display()
+        ).display() # height is important to avoid spilling padding of SlideArea
         
     def stack_frames(self, b):
         "If provided argument is True, frames are stacked in one slide top to bottom incrementally, otherwise shown individually."
@@ -474,7 +497,9 @@ class Slide:
     
     @property
     def css(self):
-        return XTML(f'{self._overall_css}\n{self._css}') # Add overall CSS but self._css should override it
+        "Returns CSS for this slide including overall CSS. Used while navigating to this slide."
+        back = self._app.html('style',_build_css((f".{self._app.uid}.SlidesWrapper",), self._tcolors), css_class='jupyter-only') # don't mess export here
+        return XTML(f'{back}{self._overall_css}\n{self._css}') # Add overall CSS but self._css should override it
     
     @property
     def index(self): return self._index
@@ -518,49 +543,64 @@ class Slide:
         else:
             return self._app.code.cast('No source found!\n',language = 'markdown')
     
-    def _fix_css(self,props, this_slide=False):
+    def _fix_css(self,props, colors, this_slide=False):
+        if props is None:
+            props = {} # may be colors only
+        
         if not isinstance(props,dict):
             raise TypeError(f"expects dict, got {type(props)}")
         
+        for k,v in props.items():
+            if not isinstance(v, dict): # Don't let user modify layout with top level props
+                raise TypeError("CSS properties are not allowed at slide level. "
+                    f"If {k!r} meant to be a CSS selector, its value must be a dict, got {type(v)}")
+            sels = k.split(',') # can be multiple selectors
+            for s in sels:
+                if not s.strip():
+                    raise KeyError(f"Empty CSS selector found in {k!r}, perhaps due to extra comma?")
+                if any([c in s for c in ['^', '<']]): # avoid layout modifications by user
+                    raise KeyError(f"Tryign to access silde node with selector {s!r} in {k!r} is restricted!")
+        
+        _allowed = ['fg1', 'fg2', 'fg3', 'bg1', 'bg2', 'bg3', 'accent', 'pointer']
+        
+        for key, value in colors.items():
+            if key not in _allowed:
+                raise KeyError(f"Theme color key {key!r} not recognized. Allowed color keys are {_allowed}")
+            if not isinstance(value, str):
+                raise TypeError(f"Theme color value for key {key!r} should be str, got {type(value)}")
+        
+        self._tcolors = {f'--{k}-color':v for k,v in colors.items()} # reset to new colors each time
+        props = {**self._tcolors, **props} # allow theme colors to be used directly per slide
+        
         if not props:
             return ''
         
-        props = {k:v for k,v in props.items() if k.lstrip(' ^<')} # Don't let user access top level to modify layout
-        
-        back_props = {}
-        for k,v in props.copy().items():
-            if not isinstance(v, dict):
-                value = props.pop(k) # Remove all top level
-                if isinstance(k, str) and k.startswith('--'): # don't check others type here
-                    back_props[k] = value # Allow CSS variables at top
-                else:
-                    print(f"Ignored property {k!r}. At top level, only CSS variables are allowed, such as '--bg1-color'!")
-                    
-        _css = ''
-        if back_props:
-            _css += _build_css((f".{self._app.uid}.SlidesWrapper",), back_props)
-        
         klass = f".{self._app.uid} .SlideArea"
         if this_slide:
             klass += f".n{self.number}"
-        
-        _css += ('\n' + _build_css((klass,), props))
-        return self._app.html('style', _css)
+        return self._app.html('style', _build_css((klass,), props))
     
-    def set_css(self, this: dict=None, overall:dict=None):
+    def _set_alt_print(self):
+        alt = f'{self._css}' # XTML or str
+        if self._bg_ikws.get('src',None):
+            alt += self._get_bg_image(get_unique_css_class()) # get bg image for print and dispaly behind slides
+        self._alt_print.value = alt
+    
+    def set_css(self, this: dict=None, overall:dict=None, **theme_colors):
         """
-        Attributes at the root level of the dictionary are only picked if they are related to background. 
+        Set CSS on `this` slide or `overall` or both cases. 
         Each call will reset previous call if props given explicitly, otherwise not.
 
         ::: note-tip
             - See code`Slides.css_syntax` for information on how to write CSS dictionary.
-            - Unlike code`slides.html('style',props)`, you can set CSS variables at top level here including theme variables
-            code['css']` --fg[1,2,3]-color `,code['css']` --bg[1,2,3]-color ` and code['css']` --[accent, pointer]-color ` to tweek appearance of individual or all slides.
+            - You can set theme colors per slide. Accepted color keys are `fg1`, `fg2`, `fg3`, `bg1`, `bg2`, `bg3`, `accent` and `pointer`.
+              This does not affect overall theme colors, for that use `Slides.settings.theme.colors`.
         """
-        if this is not None:
-            self._css = self._fix_css(this, this_slide=True)
+        if theme_colors or this is not None:
+            self._css = self._fix_css(this, theme_colors, this_slide=True) # theme colors for this slide only
+            self._set_alt_print() # update alternate print content, we still need to dynamicallly set css for animations etc to work
         if overall is not None: # Avoid accidental re-write of overall CSS
-            self.__class__._overall_css = self._fix_css(overall, this_slide=False)
+            self.__class__._overall_css = self._fix_css(overall, {}, this_slide=False) # no theme colors for overall CSS
         
         # See effect of changes
         if not self._app.this: # Otherwise it has side effects
@@ -593,24 +633,35 @@ class Slide:
         filter is a CSS filter like blur(5px), grayscale() etc.
         
         ::: note-tip
-            This function enables you to add a slide purely with an image, possibly with `opacity=1` and `contain = True`.
+            - This function enables you to add a slide purely with an image, possibly with `opacity=1` and `contain = True`.
+            
+        ::: note-warning
+            - Too many slides withlarge background images may slow down the presentation/print and increase memory usage.
+            - Setting background image on a slide with frames multiplies memory usage as each frame needs to render the background.
         """
-        if not src: 
-            self._app.widgets.htmls.bglayer.value = ""  # clear
-            self._bg_image = ""
-            return
+        # We only store keywords to save memory and send image on javascript side for quick loading of images and printing
+        self._bg_ikws = {
+            'src': src, 'opacity': opacity, 'filter': filter, 'contain': contain, 
+            '_id': f"bgi-uid{self.number}", # for unique filters and styles
+        } # store for export etc
         
-        if (image := self._app.settings._resolve_img(src, '100%')):
-            self._bg_image = f"""
-            <style>
-                {background_css(opacity= opacity, filter=filter, contain=contain)}
-            </style>
-            {image}"""
-            self._app.widgets.htmls.bglayer.value = self._bg_image
+        if src is not None:
+            self._set_alt_print() # update alternate print-only content
             if not self._contents:
                 self.set_css({}) # Remove empty CSS
+            self._app.widgets.iw.msg_tojs = 'SetIMG' # if it not happens to be there yet, will be done on swicthing slides
             self._app.navigate_to(self.index) # Go there to see effects
     
+    def _get_bg_image(self, selector):
+        if (image := self._app.settings._resolve_img(self._bg_ikws.get('src',None), '100%')):
+            return f'''<div id="{self._bg_ikws['_id']}" class="BackLayer print-only">
+            <style>
+                {background_css(selector, **{k:v for k,v in self._bg_ikws.items() if k != 'src'})}
+            </style>
+            {image}
+            </div>'''
+        return ''
+    
     def _instance_animation(self,name):
         if not (name in styles.animations):
             raise KeyError(f'animation {name!r} not found. Use None to remove animation or one of {tuple(styles.animations.keys())}')
