@@ -3,6 +3,7 @@
 from ..utils import _build_css
 from ..xmd import get_unique_css_class
 from .icons import Icon
+from ._widgets import jupyter_colors
 
 _flow_selector = ":is(.jp-OutputArea-child, .columns > div, li)" #":is(.highlight code, li, tr)"
 
@@ -94,14 +95,13 @@ animations = {'zoom':'''
 
 theme_colors = {
     'Jupyter': {
-        'fg1':'var(--jp-content-font-color0,black)',
-        'fg2':'var(--jp-content-font-color3, #454545)', 
-        'fg3':'var(--jp-content-font-color2,#003366)',
-        'bg1':'var(--jp-layout-color0,white)',
-        'bg2':'var(--jp-cell-editor-background,#f7f5f5)',
-        'bg3':'var(--jp-layout-color2,#e8e8e8)',
-        'accent':'var(--jp-brand-color1,#8988)', # May be a neutral color is good for all themes for buttons
-        'pointer':'var(--jp-error-color1,#d32f2f)',
+        k: f'var({jupyter_colors[k]}, {v})' 
+        for k, v in ({
+            'fg1':'black', 'fg2':'#454545', 'fg3':'#003366',
+            'bg1':'white', 'bg2':'#f7f5f5', 'bg3':'#e8e8e8',
+            'accent':'#8988', # May be a neutral color is good for all themes for buttons
+            'pointer':'#d32f2f',
+        }).items()
     },
     'Light': { 'fg1':'black', 'fg2':'#454545', 'fg3':'#003366', 
         'bg1':'white', 'bg2':'#f7f5f5', 'bg3':'#e8e8e8',
@@ -122,6 +122,20 @@ theme_colors = {
     }   
 }
 
+def collapse_node(b):
+    "Used to collapse div in frames navigation and print mode."
+    css = {
+        'height': '0' if b else 'unset',
+        'min-height': '0' if b else 'unset', # unlike max height, it can't be none
+        'max-height': '0' if b else 'none',
+        'overflow': 'hidden' if b else 'unset',
+        'border': 'none' if b else 'unset', # just to be safe, althout output areas don't have border and others below
+        'outline': 'none' if b else 'unset',
+        'padding': '0' if b else 'unset',
+        'margin': '0' if b else 'unset',
+    }
+    return {k: f'{v} !important' for k, v in css.items()}
+
 def style_css(colors, fonts, layout, _root = False):
     uclass = get_unique_css_class()
     margin = 'auto' if layout.centered else 'unset'
@@ -272,15 +286,12 @@ def style_css(colors, fonts, layout, _root = False):
                 "align-items": "flex-start !important",
                 "justify-content": "flex-start !important",
             }),
-
-        },
-        '^.Slides-ShowFooter .SlideArea' : {
-            'padding-bottom': 'var(--paddingBottom, 22px) !important', # 20px navbar + 2px progressbar
         },
         '.SlideArea': {
+            **{f"--{k}-color":v for k,v in colors.items()}, # need for per slide based CSS set by user to not effect all
             'position': 'absolute !important',
             'width':'210mm !important', # A4 width letter page can have a little extra margin, important to have fixed width
-            'height': f'{int(210/layout.aspect)}mm !important',
+            'height': f'{int(210/layout.aspect):.1f}mm !important',
             'transform-origin': 'center !important' if layout.centered else 'left top !important',
             'transform': 'translateZ(0) scale(var(--contentScale,1)) !important', # Set by Javascript , translateZ is important to avoid blurry text
             'box-sizing': 'border-box !important',
@@ -289,6 +300,7 @@ def style_css(colors, fonts, layout, _root = False):
             'align-items': 'center !important' if layout.centered else 'baseline !important', 
             'justify-content': 'flex-start !important', # Aligns the content to the top of box to avoid hiding things
             'padding' : '16px !important', # don't make 1em to avoid zoom with fonts
+            'padding-bottom': 'var(--paddingBottom, 23px) !important',
             'overflow': 'auto !important' if layout.scroll else 'hidden !important',
             '> .jp-OutputArea': {
                 'position': 'relative !important', # absolute content should not go outside
@@ -298,6 +310,18 @@ def style_css(colors, fonts, layout, _root = False):
                 'max-width': f'{layout.width}% !important',
                 'box-sizing': 'border-box !important',
                 'overflow': 'auto !important' if layout.scroll else 'hidden !important', # needs here too besides top
+                '@media print': { # For PDF printing of frames, data-hidden set by JS
+                    '> .jp-OutputArea-child[data-hidden], .columns.writer > div[data-hidden]': {
+                        ' , *': {'visibility': 'hidden !important',}, 
+                    },
+                },
+            },
+            '@media print': { # For PDF printing dynamically set page size
+                'padding-bottom': 'var(--printPadding, var(--paddingBottom, 23px)) !important',
+                '@page': {
+                    'margin': '0 !important',
+                    'size': f'210mm {int(210/layout.aspect):.1f}mm !important', # 1pt ~ 0.35mm, so no more than one decimal required
+                },
             },
             **({'^:not(.n0) > .jp-OutputArea': { # no yoffset on title slide, leave it centered globally
                     "top": f"{layout.yoffset}% !important", 
@@ -658,5 +682,30 @@ def style_css(colors, fonts, layout, _root = False):
             'width':'100%',
             'height':'auto',    
         },
+        '.click-wrapper': { # PDF/HTML -only clicker at bottom right
+            'position': 'fixed !important',
+            'right': '16px !important', # space for slide number
+            'bottom': '2px !important',
+            'width': '110px !important',
+            'max-width': '110px !important',
+            'height': '21px !important',
+            'display': 'flex !important',
+            'z-index': '6 !important',
+            'justify-content': 'space-evenly !important',
+            '.clicker': {
+                'display':'inline-block',
+                'padding':'0 5px !important', # PDF safe
+                'flex-grow':'1',
+                'color':'var(--accent-color)',
+                'text-align':'center',
+                'font-size':'14px',
+                'text-decoration':'none !important',
+                'opacity':'0.4',
+                '^:hover': { # for exported html interactivity
+                    'color':'var(--fg1-color)',
+                    'opacity':'1',
+                },
+            },    
+        },
     })
     
\ No newline at end of file
