@@ -85,7 +85,7 @@ class _Buttons:
     """
     Instantiate under `Widgets` class only.
     """
-    prev    =  Button(icon='chevron-left',layout= Layout(width='auto',height='auto'),tooltip='Previous Slide [<, Shift + Space]').add_class('Arrows').add_class('Prev-Btn')
+    prev    =  Button(icon='chevron-left',layout= Layout(width='auto',height='auto'),tooltip='Previous Slide [<, Ctrl + Space]').add_class('Arrows').add_class('Prev-Btn')
     next    =  Button(icon='chevron-right',layout= Layout(width='auto',height='auto'),tooltip='Next Slide [>, Space]').add_class('Arrows').add_class('Next-Btn')
     panel   =  Button(icon= 'plus',layout= Layout(width='auto',height='auto'), tooltip='Open Side Panel [S]').add_class('Menu-Item').add_class('Panel-Btn')
     toc     =  Button(icon= 'plus',layout= Layout(width='auto',height='auto'), tooltip='Toggle Table of Contents').add_class('Menu-Item').add_class('Toc-Btn')
@@ -94,7 +94,9 @@ class _Buttons:
     home    =  Button(icon= 'plus',layout= Layout(width='auto',height='auto'), tooltip='Go to Title Page').add_class('Menu-Item').add_class('Home-Btn')
     end     =  Button(icon= 'plus',layout= Layout(width='auto',height='auto'), tooltip='Go To End of Slides').add_class('Menu-Item').add_class('End-Btn')
     info    =  Button(icon= 'plus',layout= Layout(width='auto',height='auto'), tooltip='Read Information').add_class('Menu-Item').add_class('Info-Btn')
-    export  =  Button(description="Export to HTML File",layout= Layout(width='auto',height='auto', margin='0 0 0 var(--jp-widgets-inline-label-width)'))
+    export  =  Button(icon='file',description="Export to HTML File",layout= Layout(width='auto',height='auto', margin='0 0 0 var(--jp-widgets-inline-label-width)'))
+    print   =  Button(icon='file-pdf',description="Print Slides",layout= Layout(width='auto',height='auto', margin='0 0 0 var(--jp-widgets-inline-label-width)'),tooltip='Ctrl + P')
+    print2  =  Button(icon='file-pdf',description="Print Slides (merged frames)",layout= Layout(width='auto',height='auto', margin='0 0 0 var(--jp-widgets-inline-label-width)'),tooltip='Ctrl + Alt + P')
 
 @dataclass(frozen=True)
 class _Toggles:
@@ -124,8 +126,6 @@ class _Htmls:
     cursor  = HTML().add_class('LaserPointer') # For beautiful cursor
     hilite  = HTML() # Updated in settings on creation. For code blocks.
     zoom    = HTML() # zoom CSS, do not add here!
-    bglayer = HTML().add_class('BackLayer') # For glass effect
-
 @dataclass(frozen=True)
 class _Checks:
     """
@@ -136,7 +136,6 @@ class _Checks:
     toast   = ipw.Checkbox(value = True, description='Notifications',layout=auto_layout)
     focus   = ipw.Checkbox(value = True, description='Auto Focus',layout=auto_layout)
     rebuild = ipw.Checkbox(value = True, description='Auto Rebuild',layout=auto_layout)
-    navgui  = ipw.Checkbox(value = True, description='Show Nav. GUI',layout=auto_layout)
     confirm = ipw.Checkbox(value = False, description='Overwrite Existing File',layout=auto_layout)
 
 @dataclass(frozen=True)
@@ -211,8 +210,11 @@ class Widgets:
                 self.theme,
                 HTML('<b>Additional Features</b>',layout = _html_layout),
                 self.checks.focus, self.checks.rebuild, self.checks.notes,
-                self.checks.toast, self.checks.navgui, self.checks.reflow, 
-                HTML(html('details',[html('summary','<b>HTML File Export</b>'), how_to_print]).value,layout = _html_layout),
+                self.checks.toast, self.checks.reflow, 
+                HTML('<b>PDF Printing (Experimental) / HTML Export</b>',layout = _html_layout),
+                HTML(html('details',[html('summary','Printing Info'), how_to_print]).value),
+                self.buttons.print, 
+                self.buttons.print2,
                 self.buttons.export,
                 self.checks.confirm,
                 self._tmp_out,
@@ -256,12 +258,10 @@ class Widgets:
                 btn.observe(close_quick_menu, names=["value"])
         
         self.mainbox = VBox([
-            self.htmls.bglayer, # should be before everything, otherwise it will cover the slide area
             self.htmls.loading, 
             self.htmls.toast,
             self.htmls.main,
             self.htmls.theme,
-            self.htmls.logo,
             self.iw,
             self._timer.widget(minimal=True),
             self.quick_menu,
@@ -275,6 +275,7 @@ class Widgets:
             self.controls, # Importnat for unique display
             self.drawer, 
             self.navbox,
+            self.htmls.logo,# on top of things
             self._snum,
             self._progbar # progressbar should come last
             ],layout= Layout(width=f'{self.sliders.width.value}vw', height=f'{int(self.sliders.width.value*9/16)}vw',margin='auto') # 9/16 is default, will change by setting
