@@ -12,7 +12,7 @@ from IPython.display import display, clear_output
 
 from .xmd import xmd, esc, fmt, get_main_ns, _matched_vars
 from .writer import hold, write
-from .formatters import bokeh2html, plt2html, serializer
+from .formatters import bokeh2html, plt2html, plt2image, serializer
 from . import utils
 from . import dashlab
 
@@ -136,6 +136,7 @@ class Slides(BaseSlides,metaclass=Singleton):
         xmd.extensions.extend(extensions) # globally once
  
         self.plt2html   = plt2html
+        self.plt2image  = plt2image
         self.bokeh2html = bokeh2html
         self.get_logo   = get_logo
         self.icon       = _Icon  # Icon is useful to add many places
@@ -188,8 +189,7 @@ class Slides(BaseSlides,metaclass=Singleton):
             if number in self._slides_dict:
                 return self._slides_dict[number]
             raise KeyError(f"Slide with number {number} was never created or may be deleted!")
-        else:
-            return super().__getattr__(name)
+        return super().__getattribute__(name)
     
     def __dir__(self):
         # To show s0, s1, s2... for existing slides in auto-completion
@@ -585,12 +585,16 @@ class Slides(BaseSlides,metaclass=Singleton):
         self.this._toc_args = (title, highlight)
         display(self.this._reset_toc()) # Must to have metadata there
     
-    def refs(self, ncol=2):
-        r"Displays references when in footnote mode. refs are set in `Slides.set_citations`. In markdown, use refs\`ncol\` syntax."
+    def refs(self, ncol=2, *keys):
+        r"""Displays references when in footnote mode (explicit use on slides with frames required). 
+        References are set in `Slides.set_citations`. In markdown, use refs\`ncol\` syntax.
+        You can optionally provide keys to show only specific citations at a place, which is useful on slides with frames.
+        """
         self.verify_running("refs can only be added under slides constructor!")
         self.this._set_refs = False # already added here
+        objs = self.this._citations.values() if not keys else [v for k,v in self.this._citations.items() if k in keys]
         if self._cite_mode == "footnote":
-            _cits = ''.join(v.value for v in sorted(self.this._citations.values(), key=lambda x: x._id))
+            _cits = ''.join(v.value for v in sorted(objs, key=lambda x: x._id))
             return self.html("div", _cits, css_class = 'Citations text-small', 
                 style = f'column-count: {ncol} !important;')
 
@@ -851,9 +855,7 @@ class Slides(BaseSlides,metaclass=Singleton):
             if btn:
                 self.notify('Widgets updated everywhere!')
             
-            if self._current:
-                self.settings._get_footer(self._current, update_widget=True) # sometimes it is not updated due to message lost, so force it too
-            
+            self.settings.footer._apply_change(None) # sometimes it is not updated due to message lost, so force it too
             self._current._set_progress() # update display can take it over to other sldies
 
     def _collect_slides(self):
@@ -866,12 +868,6 @@ class Slides(BaseSlides,metaclass=Singleton):
 
         return slides_iterable
     
-    def _sec_id2dom(self):
-        self.widgets.iw._slides_ids = ids = ",".join(
-            s._sec_id if s._section else "" for s in self._iterable
-        )  # Set ids for slides in DOM if section is set
-        self.widgets.iw.msg_tojs = "ToggleID:" + ids # send as well, but keep reerence for when displayed
-
     def _update_toc(self):
         tocs = [(s.index, s._section) for s in self._iterable if s._section]
         children = [
@@ -887,7 +883,6 @@ class Slides(BaseSlides,metaclass=Singleton):
             children.append(self._toc_widget)
 
         self.widgets.tocbox.children = children
-        self._sec_id2dom()
 
     def create(self, slide_numbers):
         "Create empty slides with given slide numbers. If a slide already exists, it remains same. This is much faster than creating one slide each time."
@@ -934,9 +929,14 @@ class fsep:
     def __init__(self, stack=None):
         app = self._app_ins()
         app.verify_running("Cant use fsep in a capture context other than slides!")
-        app.this._widget.add_class("Frames")
-        app.this._fsep = getattr(app.this, '_fsep',app.html('style','').as_widget()) # create once
-        app.frozen(app.this._fsep, {"FSEP": "","skip-export":"no need in export"}).display()
+        app.this._widget.add_class("base") # this is needed to distinguisg clones during printing
+        
+        sep = app.html('')
+        if not hasattr(app.this, '_fsep'): 
+            sep = sep.as_widget() # first separator must be a widget
+            app.this._fsep = sep # this is used to change frames dynamically
+        
+        display(sep, metadata={"FSEP": "","skip-export":"no need in export"})
         
         if stack in (True, False):
             app.this.stack_frames(stack)
