@@ -175,9 +175,10 @@ def resolve_objs_on_slide(xmd_instance, slide_instance, text_chunk):
         text_chunk = text_chunk.replace(f"toc{hl}`{title}`", xmd_instance._handle_var(slide_instance.this._reset_toc()), 1)
 
     # Footnotes at place user likes
-    all_matches = re.findall(r"refs\`([\d+]?)\`", text_chunk) # match digit or empty
+    all_matches = re.findall(r"refs\`(.*?)\`", text_chunk, flags=re.DOTALL) # match digit or empty
     for match in all_matches:
-        out = xmd_instance._handle_var(slide_instance.refs(match or int(match))) # match is empty or digit
+        ncol, *keys = [v.strip() for v in match.split(',')]
+        out = xmd_instance._handle_var(slide_instance.refs(int(ncol) if ncol.isdigit() else 2, *keys)) # match is empty or digit and keys
         text_chunk = text_chunk.replace(f"refs`{match}`", out, 1)
     return text_chunk
 
@@ -337,11 +338,15 @@ class XMarkdown(Markdown):
             self._wr_imported = writer
         return self._wr_imported
     
+    @property
+    def _running_md_slide(self): # checks if parsing under purely markdown slide
+        return self._slides and self._slides.this and self._slides.this._markdown
+    
     def user_ns(self):
         "Top level namespace or set by user inside `Slides.fmt`."
         if self._fmt_ns: 
             return self._fmt_ns # always preferred
-        elif self._slides and self._slides.this and self._slides.this._markdown:
+        elif self._running_md_slide:
             return { 
                 **self._slides._nb_vars, # Top level notebook scope variables
                 **self._slides.this._md_vars, # by Slide
@@ -755,6 +760,9 @@ class XMarkdown(Markdown):
                 
                 if key not in user_ns: # top level var without ., indexing not found
                     err = error('NameError', f'name {key!r} is not defined')
+                    if self._running_md_slide: # under slide building purely from markdown
+                        err = err.value + ("You can update this variable by `Slides[int,|list|slice].vars.update` "
+                            "or by defining it in notebook if `Auto Rebuild` is enabled.")
                     return self._handle_var(error('Exception', f'Could not resolve {match.group()!r}:\n{err}'))
 
                 cmatch = match.group()[2:-1].strip().split('!')[0] # conversion split
